summaryrefslogtreecommitdiff
path: root/animations
diff options
context:
space:
mode:
Diffstat (limited to 'animations')
-rw-r--r--animations/inc/animations/animationnodehelper.hxx3
-rw-r--r--animations/source/animcore/animcore.cxx7
-rw-r--r--animations/source/animcore/animcore.xml2
-rw-r--r--animations/source/animcore/factreg.cxx3
-rw-r--r--animations/source/animcore/factreg.hxx3
-rw-r--r--animations/source/animcore/makefile.mk12
-rw-r--r--animations/source/animcore/targetpropertiescreator.cxx9
7 files changed, 23 insertions, 16 deletions
diff --git a/animations/inc/animations/animationnodehelper.hxx b/animations/inc/animations/animationnodehelper.hxx
index 8857c52942ce..969e3326105d 100644
--- a/animations/inc/animations/animationnodehelper.hxx
+++ b/animations/inc/animations/animationnodehelper.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -128,3 +129,5 @@ namespace anim
}
#endif /* INCLUDED_ANIMATIONS_ANIMATIONNODEHELPER_HXX */
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/animations/source/animcore/animcore.cxx b/animations/source/animcore/animcore.cxx
index 7b18a83e2fe4..ec151c6bc870 100644
--- a/animations/source/animcore/animcore.cxx
+++ b/animations/source/animcore/animcore.cxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -242,8 +243,6 @@ public:
virtual void SAL_CALL setSubtype( sal_Int16 _subtype ) throw (RuntimeException);
virtual sal_Bool SAL_CALL getMode() throw (RuntimeException);
virtual void SAL_CALL setMode( sal_Bool _mode ) throw (RuntimeException);
-// virtual sal_Bool SAL_CALL getDirection() throw (RuntimeException);
-// virtual void SAL_CALL setDirection( sal_Bool _direction ) throw (RuntimeException);
virtual sal_Int32 SAL_CALL getFadeColor() throw (RuntimeException);
virtual void SAL_CALL setFadeColor( sal_Int32 _fadecolor ) throw (RuntimeException);
@@ -254,7 +253,7 @@ public:
virtual void SAL_CALL setVolume( double _volume ) throw (RuntimeException);
- // XCommand
+ // XCommand - the following two shadowed by animate, unfortunately
// virtual Any SAL_CALL getTarget() throw (RuntimeException);
// virtual void SAL_CALL setTarget( const Any& _target ) throw (RuntimeException);
virtual sal_Int16 SAL_CALL getCommand() throw (RuntimeException);
@@ -2087,3 +2086,5 @@ void AnimationNode::fireChangeListener()
// --------------------------------------------------------------------
} // namespace animcore
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/animations/source/animcore/animcore.xml b/animations/source/animcore/animcore.xml
index 9ccca0f02081..f6d105ea0794 100644
--- a/animations/source/animcore/animcore.xml
+++ b/animations/source/animcore/animcore.xml
@@ -19,12 +19,10 @@
<project-build-dependency> cppuhelper </project-build-dependency>
<project-build-dependency> cppu </project-build-dependency>
- <project-build-dependency> vos </project-build-dependency>
<project-build-dependency> sal </project-build-dependency>
<runtime-module-dependency> cppuhelper </runtime-module-dependency>
<runtime-module-dependency> cppu2 </runtime-module-dependency>
- <runtime-module-dependency> vos2MSC </runtime-module-dependency>
<runtime-module-dependency> sal2 </runtime-module-dependency>
</module-description>
diff --git a/animations/source/animcore/factreg.cxx b/animations/source/animcore/factreg.cxx
index ce12955f4125..c79ac7d7852b 100644
--- a/animations/source/animcore/factreg.cxx
+++ b/animations/source/animcore/factreg.cxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -92,3 +93,5 @@ void * SAL_CALL component_getFactory(
}
}
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/animations/source/animcore/factreg.hxx b/animations/source/animcore/factreg.hxx
index b76fc1067e0c..c877d1b53c95 100644
--- a/animations/source/animcore/factreg.hxx
+++ b/animations/source/animcore/factreg.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -49,3 +50,5 @@ DECL_NODE_FACTORY( COMMAND );
DECL_NODE_FACTORY( TargetPropertiesCreator );
}
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/animations/source/animcore/makefile.mk b/animations/source/animcore/makefile.mk
index 674858cd50d0..9c6b4a2cdead 100644
--- a/animations/source/animcore/makefile.mk
+++ b/animations/source/animcore/makefile.mk
@@ -24,24 +24,21 @@
# for a copy of the LGPLv3 License.
#
#*************************************************************************
+
PRJ=..$/..
PRJNAME=animations
TARGET=animcore
ENABLE_EXCEPTIONS=TRUE
NO_BSYMBOLIC=TRUE
-#COMP1TYPELIST=$(TARGET)
-#COMPRDB=$(SOLARBINDIR)$/offapi.rdb
# --- Settings -----------------------------------------------------
+
.INCLUDE : settings.mk
+
.IF "$(L10N_framework)"==""
-# --- Files --------------------------------------------------------
-#UNOUCRDEP=$(SOLARBINDIR)$/offapi.rdb
-#UNOUCRRDB=$(SOLARBINDIR)$/offapi.rdb
-#UNOUCROUT=$(OUT)$/inc$/animations
-#INCPRE+= $(UNOUCROUT)
+# --- Files --------------------------------------------------------
SLOFILES = $(SLO)$/animcore.obj\
$(SLO)$/factreg.obj\
@@ -68,7 +65,6 @@ DEF1NAME= $(SHL1TARGET)
# --- Targets ------------------------------------------------------
.INCLUDE : target.mk
-
ALLTAR : $(MISC)/animcore.component
$(MISC)/animcore.component .ERRREMOVE : $(SOLARENV)/bin/createcomponent.xslt \
diff --git a/animations/source/animcore/targetpropertiescreator.cxx b/animations/source/animcore/targetpropertiescreator.cxx
index b36694bac0ab..ca8ce793f744 100644
--- a/animations/source/animcore/targetpropertiescreator.cxx
+++ b/animations/source/animcore/targetpropertiescreator.cxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -48,7 +49,7 @@
#include <animations/animationnodehelper.hxx>
#include <vector>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
using namespace ::com::sun::star;
@@ -140,7 +141,7 @@ namespace animcore
*/
sal_Int16 mnParagraphIndex;
/// Comparison needed for hash_map
bool operator==( const ShapeHashKey& rRHS ) const
{
return mxRef == rRHS.mxRef && mnParagraphIndex == rRHS.mnParagraphIndex;
@@ -148,7 +149,7 @@ namespace animcore
};
// A hash map which maps a XShape to the corresponding vector of initial properties
- typedef ::std::hash_map< ShapeHashKey,
+ typedef ::boost::unordered_map< ShapeHashKey,
VectorOfNamedValues,
::std::size_t (*)(const ShapeHashKey&) > XShapeHash;
@@ -501,3 +502,5 @@ namespace animcore
}
} // namespace animcore
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
@@ -140,7 +141,7 @@ namespace animcore
*/
sal_Int16 mnParagraphIndex;
- /// Comparison needed for hash_map
+ /// Comparison needed for boost::unordered_map
bool operator==( const ShapeHashKey& rRHS ) const
{